const { execa } = require('@vue/cli-shared-utils')

module.exports = (api, options) => {
  api.render('./template', {
    doesCompile: api.hasPlugin('babel') || api.hasPlugin('typescript')
  })

  api.extendPackage({
    scripts: {
      'serve': 'vue-cli-service serve',
      'build': 'vue-cli-service build'
    },
    dependencies: {
      'vue': '^2.6.10'
    },
    devDependencies: {
      'vue-template-compiler': '^2.6.10'
    },
    'postcss': {
      'plugins': {
        'autoprefixer': {}
      }
    },
    browserslist: [
      '> 1%',
      'last 2 versions'
    ]
  })

  if (options.cssPreprocessor) {
    const deps = {
      sass: {
        sass: '^1.19.0',
        'sass-loader': '^8.0.0'
      },
      'node-sass': {
        'node-sass': '^4.12.0',
        'sass-loader': '^8.0.0'
      },
      'dart-sass': {
        sass: '^1.19.0',
        'sass-loader': '^8.0.0'
      },
      less: {
        'less': '^3.0.4',
        'less-loader': '^5.0.0'
      },
      stylus: {
        'stylus': '^0.54.5',
        'stylus-loader': '^3.0.2'
      }
    }

    api.extendPackage({
      devDependencies: deps[options.cssPreprocessor]
    })
  }

  // for v3 compatibility
  if (options.router && !api.hasPlugin('router')) {
    api.extendPackage({
      devDependencies: {
        '@vue/cli-plugin-router': '^4.0.0'
      }
    })

    api.onCreateComplete(() => {
      execa.sync('vue', [
        'invoke',
        '@vue/cli-plugin-router',
        `--historyMode=${options.routerHistoryMode ? 'true' : ''}`
      ], {
        cwd: api.resolve('.')
      })
    })
  }

  // for v3 compatibility
  if (options.vuex && !api.hasPlugin('vuex')) {
    api.extendPackage({
      devDependencies: {
        '@vue/cli-plugin-vuex': '^4.0.0'
      }
    })

    api.onCreateComplete(() => {
      execa.sync('vue', [
        'invoke',
        '@vue/cli-plugin-vuex'
      ], {
        cwd: api.resolve('.')
      })
    })
  }

  // additional tooling configurations
  if (options.configs) {
    api.extendPackage(options.configs)
  }
}
